@@ -1,7 +1,7 @@
 package Perinci::CmdLine::POD;
 
-our $DATE = '2017-01-27'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $DATE = '2017-02-13'; # DATE
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use strict;
@@ -681,7 +681,7 @@ sub gen_pod_for_pericmd_script {
         my $completer_name = $args{completer_script};
         last unless defined $completer_name;
         my $self_completing;
-        if ($completer_name eq ':self') {
+        if ($completer_name eq ':self' || $completer_name eq $program_name) {
             $self_completing = 1;
             $completer_name = $program_name;
         }
@@ -967,7 +967,7 @@ Perinci::CmdLine::POD - Generate POD for Perinci::CmdLine-based CLI script
 
 =head1 VERSION
 
-This document describes version 0.008 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2017-01-27.
+This document describes version 0.009 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2017-02-13.
 
 =head1 SYNOPSIS
 
@@ -978,7 +978,11 @@ Please see the included CLI script L<gen-pod-for-pericmd-script>.
 =head1 FUNCTIONS
 
 
-=head2 gen_pod_for_pericmd_script(%args) -> [status, msg, result, meta]
+=head2 gen_pod_for_pericmd_script
+
+Usage:
+
+ gen_pod_for_pericmd_script(%args) -> [status, msg, result, meta]
 
 Generate POD for Perinci::CmdLine-based CLI script.
 
